# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import definitions_pb2 as definitions__pb2
from . import peers_pb2 as peers__pb2
from . import media_and_files_pb2 as media__and__files__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='spaces.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cspaces.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x0bpeers.proto\x1a\x15media_and_files.proto\x1a\x15scalapb/scalapb.proto\"\xef\x03\n\x05Space\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x07general\x18\x03 \x01(\x0b\x32\x15.dialog.Space.GeneralH\x00\x12&\n\x06public\x18\x04 \x01(\x0b\x32\x14.dialog.Space.PublicH\x00\x12(\n\x07private\x18\x05 \x01(\x0b\x32\x15.dialog.Space.PrivateH\x00\x12\r\n\x05title\x18\x06 \x01(\t\x12+\n\x05\x61\x62out\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1e\n\x06\x61vatar\x18\x08 \x01(\x0b\x32\x0e.dialog.Avatar\x12.\n\ndeleted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x05\x63lock\x18\n \x01(\x0b\x32\x11.dialog.DataClock\x1a\t\n\x07General\x1a\x32\n\x06Public\x12\x15\n\rowner_user_id\x18\x01 \x01(\x05\x12\x11\n\tshortname\x18\x02 \x01(\t\x1a \n\x07Private\x12\x15\n\rowner_user_id\x18\x01 \x01(\x05\x42\x0c\n\nspace_type\"\xf4\x01\n\x0bSpaceMember\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12.\n\ninvited_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tjoined_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x05\x63lock\x18\x06 \x01(\x0b\x32\x11.dialog.DataClock\"3\n\x13UpdateSpaceModified\x12\x1c\n\x05space\x18\x01 \x01(\x0b\x32\r.dialog.Space\"@\n\x19UpdateSpaceMemberModified\x12#\n\x06member\x18\x01 \x01(\x0b\x32\x13.dialog.SpaceMember\"\xd3\x01\n\x12RequestCreateSpace\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12/\n\tshortname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x61\x62out\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1e\n\x06\x61vatar\x18\x05 \x01(\x0b\x32\x0e.dialog.Avatar:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"L\n\rResponseSpace\x12\x1c\n\x05space\x18\x01 \x01(\x0b\x32\r.dialog.Space:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"~\n\x13ResponseSpaceMember\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12#\n\x06member\x18\x02 \x01(\x0b\x32\x13.dialog.SpaceMember:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"s\n\x12RequestDeleteSpace\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12 \n\x05\x63lock\x18\x02 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"1\n\x11RequestLoadSpaces:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"{\n\x12ResponseLoadSpaces\x12\x1c\n\x05space\x18\x01 \x03(\x0b\x32\r.dialog.Space\x12(\n\x0bowner_peers\x18\x02 \x03(\x0b\x32\x13.dialog.UserOutPeer:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"\x80\x01\n\x19RequestStreamSpaceMembers\x12#\n\x08space_id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12 \n\x05\x63lock\x18\x02 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"]\n\x13SpaceMemberWithPeer\x12#\n\x06member\x18\x01 \x01(\x0b\x32\x13.dialog.SpaceMember\x12!\n\x04peer\x18\x02 \x01(\x0b\x32\x13.dialog.UserOutPeer\"\x7f\n\x0fRequestSetTitle\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\r\n\x05title\x18\x02 \x01(\t\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\xa5\x01\n\x13RequestSetShortname\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12/\n\tshortname\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9d\x01\n\x0fRequestSetAbout\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12+\n\x05\x61\x62out\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9e\x01\n\x10RequestSetAvatar\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12+\n\rfile_location\x18\x02 \x01(\x0b\x32\x14.dialog.FileLocation\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x84\x01\n\x12RequestSpaceInvite\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x82\x01\n\x10RequestSpaceKick\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x83\x01\n\x11RequestSpaceLeave\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12 \n\x05\x63lock\x18\x03 \x01(\x0b\x32\x11.dialog.DataClock:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"W\n\x18RequestGetSpaceInviteUrl\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"K\n\x16ResponseSpaceInviteUrl\x12\x12\n\ninvite_url\x18\x01 \x01(\t:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"Z\n\x1bRequestRevokeSpaceInviteUrl\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest2\xb2\x07\n\x06Spaces\x12\x42\n\x0b\x43reateSpace\x12\x1a.dialog.RequestCreateSpace\x1a\x15.dialog.ResponseSpace\"\x00\x12\x42\n\x0b\x44\x65leteSpace\x12\x1a.dialog.RequestDeleteSpace\x1a\x15.dialog.ResponseSpace\"\x00\x12<\n\x08SetTitle\x12\x17.dialog.RequestSetTitle\x1a\x15.dialog.ResponseSpace\"\x00\x12\x44\n\x0cSetShortname\x12\x1b.dialog.RequestSetShortname\x1a\x15.dialog.ResponseSpace\"\x00\x12<\n\x08SetAbout\x12\x17.dialog.RequestSetAbout\x1a\x15.dialog.ResponseSpace\"\x00\x12>\n\tSetAvatar\x12\x18.dialog.RequestSetAvatar\x1a\x15.dialog.ResponseSpace\"\x00\x12\x45\n\nLoadSpaces\x12\x19.dialog.RequestLoadSpaces\x1a\x1a.dialog.ResponseLoadSpaces\"\x00\x12V\n\x10LoadSpaceMembers\x12!.dialog.RequestStreamSpaceMembers\x1a\x1b.dialog.SpaceMemberWithPeer\"\x00\x30\x01\x12\x43\n\x06Invite\x12\x1a.dialog.RequestSpaceInvite\x1a\x1b.dialog.ResponseSpaceMember\"\x00\x12?\n\x04Kick\x12\x18.dialog.RequestSpaceKick\x1a\x1b.dialog.ResponseSpaceMember\"\x00\x12\x41\n\x05Leave\x12\x19.dialog.RequestSpaceLeave\x1a\x1b.dialog.ResponseSpaceMember\"\x00\x12W\n\x11GetSpaceInviteUrl\x12 .dialog.RequestGetSpaceInviteUrl\x1a\x1e.dialog.ResponseSpaceInviteUrl\"\x00\x12]\n\x14RevokeSpaceInviteUrl\x12#.dialog.RequestRevokeSpaceInviteUrl\x1a\x1e.dialog.ResponseSpaceInviteUrl\"\x00\x42\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,media__and__files__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_SPACE_GENERAL = _descriptor.Descriptor(
  name='General',
  full_name='dialog.Space.General',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=563,
)

_SPACE_PUBLIC = _descriptor.Descriptor(
  name='Public',
  full_name='dialog.Space.Public',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='dialog.Space.Public.owner_user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.Space.Public.shortname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=615,
)

_SPACE_PRIVATE = _descriptor.Descriptor(
  name='Private',
  full_name='dialog.Space.Private',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_user_id', full_name='dialog.Space.Private.owner_user_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=649,
)

_SPACE = _descriptor.Descriptor(
  name='Space',
  full_name='dialog.Space',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.Space.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='dialog.Space.created_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='general', full_name='dialog.Space.general', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='dialog.Space.public', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private', full_name='dialog.Space.private', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.Space.title', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.Space.about', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.Space.avatar', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='dialog.Space.deleted_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.Space.clock', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SPACE_GENERAL, _SPACE_PUBLIC, _SPACE_PRIVATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='space_type', full_name='dialog.Space.space_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=168,
  serialized_end=663,
)


_SPACEMEMBER = _descriptor.Descriptor(
  name='SpaceMember',
  full_name='dialog.SpaceMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.SpaceMember.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.SpaceMember.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invited_at', full_name='dialog.SpaceMember.invited_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joined_at', full_name='dialog.SpaceMember.joined_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deleted_at', full_name='dialog.SpaceMember.deleted_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.SpaceMember.clock', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=910,
)


_UPDATESPACEMODIFIED = _descriptor.Descriptor(
  name='UpdateSpaceModified',
  full_name='dialog.UpdateSpaceModified',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='dialog.UpdateSpaceModified.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=963,
)


_UPDATESPACEMEMBERMODIFIED = _descriptor.Descriptor(
  name='UpdateSpaceMemberModified',
  full_name='dialog.UpdateSpaceMemberModified',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.UpdateSpaceMemberModified.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1029,
)


_REQUESTCREATESPACE = _descriptor.Descriptor(
  name='RequestCreateSpace',
  full_name='dialog.RequestCreateSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='dialog.RequestCreateSpace.request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestCreateSpace.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestCreateSpace.shortname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestCreateSpace.about', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='dialog.RequestCreateSpace.avatar', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1032,
  serialized_end=1243,
)


_RESPONSESPACE = _descriptor.Descriptor(
  name='ResponseSpace',
  full_name='dialog.ResponseSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='dialog.ResponseSpace.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1321,
)


_RESPONSESPACEMEMBER = _descriptor.Descriptor(
  name='ResponseSpaceMember',
  full_name='dialog.ResponseSpaceMember',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.ResponseSpaceMember.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.ResponseSpaceMember.member', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1449,
)


_REQUESTDELETESPACE = _descriptor.Descriptor(
  name='RequestDeleteSpace',
  full_name='dialog.RequestDeleteSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestDeleteSpace.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestDeleteSpace.clock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1451,
  serialized_end=1566,
)


_REQUESTLOADSPACES = _descriptor.Descriptor(
  name='RequestLoadSpaces',
  full_name='dialog.RequestLoadSpaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1617,
)


_RESPONSELOADSPACES = _descriptor.Descriptor(
  name='ResponseLoadSpaces',
  full_name='dialog.ResponseLoadSpaces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='dialog.ResponseLoadSpaces.space', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_peers', full_name='dialog.ResponseLoadSpaces.owner_peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1742,
)


_REQUESTSTREAMSPACEMEMBERS = _descriptor.Descriptor(
  name='RequestStreamSpaceMembers',
  full_name='dialog.RequestStreamSpaceMembers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='dialog.RequestStreamSpaceMembers.space_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestStreamSpaceMembers.clock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1745,
  serialized_end=1873,
)


_SPACEMEMBERWITHPEER = _descriptor.Descriptor(
  name='SpaceMemberWithPeer',
  full_name='dialog.SpaceMemberWithPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member', full_name='dialog.SpaceMemberWithPeer.member', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.SpaceMemberWithPeer.peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1968,
)


_REQUESTSETTITLE = _descriptor.Descriptor(
  name='RequestSetTitle',
  full_name='dialog.RequestSetTitle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetTitle.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='dialog.RequestSetTitle.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetTitle.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1970,
  serialized_end=2097,
)


_REQUESTSETSHORTNAME = _descriptor.Descriptor(
  name='RequestSetShortname',
  full_name='dialog.RequestSetShortname',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetShortname.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortname', full_name='dialog.RequestSetShortname.shortname', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetShortname.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2265,
)


_REQUESTSETABOUT = _descriptor.Descriptor(
  name='RequestSetAbout',
  full_name='dialog.RequestSetAbout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetAbout.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='about', full_name='dialog.RequestSetAbout.about', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetAbout.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2425,
)


_REQUESTSETAVATAR = _descriptor.Descriptor(
  name='RequestSetAvatar',
  full_name='dialog.RequestSetAvatar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSetAvatar.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_location', full_name='dialog.RequestSetAvatar.file_location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSetAvatar.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2428,
  serialized_end=2586,
)


_REQUESTSPACEINVITE = _descriptor.Descriptor(
  name='RequestSpaceInvite',
  full_name='dialog.RequestSpaceInvite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSpaceInvite.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.RequestSpaceInvite.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSpaceInvite.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2589,
  serialized_end=2721,
)


_REQUESTSPACEKICK = _descriptor.Descriptor(
  name='RequestSpaceKick',
  full_name='dialog.RequestSpaceKick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSpaceKick.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.RequestSpaceKick.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSpaceKick.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2724,
  serialized_end=2854,
)


_REQUESTSPACELEAVE = _descriptor.Descriptor(
  name='RequestSpaceLeave',
  full_name='dialog.RequestSpaceLeave',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestSpaceLeave.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='dialog.RequestSpaceLeave.user_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.RequestSpaceLeave.clock', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2857,
  serialized_end=2988,
)


_REQUESTGETSPACEINVITEURL = _descriptor.Descriptor(
  name='RequestGetSpaceInviteUrl',
  full_name='dialog.RequestGetSpaceInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestGetSpaceInviteUrl.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3077,
)


_RESPONSESPACEINVITEURL = _descriptor.Descriptor(
  name='ResponseSpaceInviteUrl',
  full_name='dialog.ResponseSpaceInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='invite_url', full_name='dialog.ResponseSpaceInviteUrl.invite_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3079,
  serialized_end=3154,
)


_REQUESTREVOKESPACEINVITEURL = _descriptor.Descriptor(
  name='RequestRevokeSpaceInviteUrl',
  full_name='dialog.RequestRevokeSpaceInviteUrl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.RequestRevokeSpaceInviteUrl.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3156,
  serialized_end=3246,
)

_SPACE_GENERAL.containing_type = _SPACE
_SPACE_PUBLIC.containing_type = _SPACE
_SPACE_PRIVATE.containing_type = _SPACE
_SPACE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_SPACE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACE.fields_by_name['general'].message_type = _SPACE_GENERAL
_SPACE.fields_by_name['public'].message_type = _SPACE_PUBLIC
_SPACE.fields_by_name['private'].message_type = _SPACE_PRIVATE
_SPACE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SPACE.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_SPACE.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_SPACE.oneofs_by_name['space_type'].fields.append(
  _SPACE.fields_by_name['general'])
_SPACE.fields_by_name['general'].containing_oneof = _SPACE.oneofs_by_name['space_type']
_SPACE.oneofs_by_name['space_type'].fields.append(
  _SPACE.fields_by_name['public'])
_SPACE.fields_by_name['public'].containing_oneof = _SPACE.oneofs_by_name['space_type']
_SPACE.oneofs_by_name['space_type'].fields.append(
  _SPACE.fields_by_name['private'])
_SPACE.fields_by_name['private'].containing_oneof = _SPACE.oneofs_by_name['space_type']
_SPACEMEMBER.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_SPACEMEMBER.fields_by_name['invited_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACEMEMBER.fields_by_name['joined_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACEMEMBER.fields_by_name['deleted_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SPACEMEMBER.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_UPDATESPACEMODIFIED.fields_by_name['space'].message_type = _SPACE
_UPDATESPACEMEMBERMODIFIED.fields_by_name['member'].message_type = _SPACEMEMBER
_REQUESTCREATESPACE.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTCREATESPACE.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTCREATESPACE.fields_by_name['avatar'].message_type = media__and__files__pb2._AVATAR
_RESPONSESPACE.fields_by_name['space'].message_type = _SPACE
_RESPONSESPACEMEMBER.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_RESPONSESPACEMEMBER.fields_by_name['member'].message_type = _SPACEMEMBER
_REQUESTDELETESPACE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTDELETESPACE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_RESPONSELOADSPACES.fields_by_name['space'].message_type = _SPACE
_RESPONSELOADSPACES.fields_by_name['owner_peers'].message_type = peers__pb2._USEROUTPEER
_REQUESTSTREAMSPACEMEMBERS.fields_by_name['space_id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSTREAMSPACEMEMBERS.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_SPACEMEMBERWITHPEER.fields_by_name['member'].message_type = _SPACEMEMBER
_SPACEMEMBERWITHPEER.fields_by_name['peer'].message_type = peers__pb2._USEROUTPEER
_REQUESTSETTITLE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETTITLE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSETSHORTNAME.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETSHORTNAME.fields_by_name['shortname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSETSHORTNAME.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSETABOUT.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETABOUT.fields_by_name['about'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REQUESTSETABOUT.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSETAVATAR.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSETAVATAR.fields_by_name['file_location'].message_type = media__and__files__pb2._FILELOCATION
_REQUESTSETAVATAR.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSPACEINVITE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSPACEINVITE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSPACEKICK.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSPACEKICK.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTSPACELEAVE.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTSPACELEAVE.fields_by_name['clock'].message_type = definitions__pb2._DATACLOCK
_REQUESTGETSPACEINVITEURL.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
_REQUESTREVOKESPACEINVITEURL.fields_by_name['id'].message_type = definitions__pb2._UUIDVALUE
DESCRIPTOR.message_types_by_name['Space'] = _SPACE
DESCRIPTOR.message_types_by_name['SpaceMember'] = _SPACEMEMBER
DESCRIPTOR.message_types_by_name['UpdateSpaceModified'] = _UPDATESPACEMODIFIED
DESCRIPTOR.message_types_by_name['UpdateSpaceMemberModified'] = _UPDATESPACEMEMBERMODIFIED
DESCRIPTOR.message_types_by_name['RequestCreateSpace'] = _REQUESTCREATESPACE
DESCRIPTOR.message_types_by_name['ResponseSpace'] = _RESPONSESPACE
DESCRIPTOR.message_types_by_name['ResponseSpaceMember'] = _RESPONSESPACEMEMBER
DESCRIPTOR.message_types_by_name['RequestDeleteSpace'] = _REQUESTDELETESPACE
DESCRIPTOR.message_types_by_name['RequestLoadSpaces'] = _REQUESTLOADSPACES
DESCRIPTOR.message_types_by_name['ResponseLoadSpaces'] = _RESPONSELOADSPACES
DESCRIPTOR.message_types_by_name['RequestStreamSpaceMembers'] = _REQUESTSTREAMSPACEMEMBERS
DESCRIPTOR.message_types_by_name['SpaceMemberWithPeer'] = _SPACEMEMBERWITHPEER
DESCRIPTOR.message_types_by_name['RequestSetTitle'] = _REQUESTSETTITLE
DESCRIPTOR.message_types_by_name['RequestSetShortname'] = _REQUESTSETSHORTNAME
DESCRIPTOR.message_types_by_name['RequestSetAbout'] = _REQUESTSETABOUT
DESCRIPTOR.message_types_by_name['RequestSetAvatar'] = _REQUESTSETAVATAR
DESCRIPTOR.message_types_by_name['RequestSpaceInvite'] = _REQUESTSPACEINVITE
DESCRIPTOR.message_types_by_name['RequestSpaceKick'] = _REQUESTSPACEKICK
DESCRIPTOR.message_types_by_name['RequestSpaceLeave'] = _REQUESTSPACELEAVE
DESCRIPTOR.message_types_by_name['RequestGetSpaceInviteUrl'] = _REQUESTGETSPACEINVITEURL
DESCRIPTOR.message_types_by_name['ResponseSpaceInviteUrl'] = _RESPONSESPACEINVITEURL
DESCRIPTOR.message_types_by_name['RequestRevokeSpaceInviteUrl'] = _REQUESTREVOKESPACEINVITEURL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Space = _reflection.GeneratedProtocolMessageType('Space', (_message.Message,), {

  'General' : _reflection.GeneratedProtocolMessageType('General', (_message.Message,), {
    'DESCRIPTOR' : _SPACE_GENERAL,
    '__module__' : 'spaces_pb2'
    # @@protoc_insertion_point(class_scope:dialog.Space.General)
    })
  ,

  'Public' : _reflection.GeneratedProtocolMessageType('Public', (_message.Message,), {
    'DESCRIPTOR' : _SPACE_PUBLIC,
    '__module__' : 'spaces_pb2'
    # @@protoc_insertion_point(class_scope:dialog.Space.Public)
    })
  ,

  'Private' : _reflection.GeneratedProtocolMessageType('Private', (_message.Message,), {
    'DESCRIPTOR' : _SPACE_PRIVATE,
    '__module__' : 'spaces_pb2'
    # @@protoc_insertion_point(class_scope:dialog.Space.Private)
    })
  ,
  'DESCRIPTOR' : _SPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.Space)
  })
_sym_db.RegisterMessage(Space)
_sym_db.RegisterMessage(Space.General)
_sym_db.RegisterMessage(Space.Public)
_sym_db.RegisterMessage(Space.Private)

SpaceMember = _reflection.GeneratedProtocolMessageType('SpaceMember', (_message.Message,), {
  'DESCRIPTOR' : _SPACEMEMBER,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SpaceMember)
  })
_sym_db.RegisterMessage(SpaceMember)

UpdateSpaceModified = _reflection.GeneratedProtocolMessageType('UpdateSpaceModified', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEMODIFIED,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateSpaceModified)
  })
_sym_db.RegisterMessage(UpdateSpaceModified)

UpdateSpaceMemberModified = _reflection.GeneratedProtocolMessageType('UpdateSpaceMemberModified', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEMEMBERMODIFIED,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdateSpaceMemberModified)
  })
_sym_db.RegisterMessage(UpdateSpaceMemberModified)

RequestCreateSpace = _reflection.GeneratedProtocolMessageType('RequestCreateSpace', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCREATESPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestCreateSpace)
  })
_sym_db.RegisterMessage(RequestCreateSpace)

ResponseSpace = _reflection.GeneratedProtocolMessageType('ResponseSpace', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSpace)
  })
_sym_db.RegisterMessage(ResponseSpace)

ResponseSpaceMember = _reflection.GeneratedProtocolMessageType('ResponseSpaceMember', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESPACEMEMBER,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSpaceMember)
  })
_sym_db.RegisterMessage(ResponseSpaceMember)

RequestDeleteSpace = _reflection.GeneratedProtocolMessageType('RequestDeleteSpace', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDELETESPACE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestDeleteSpace)
  })
_sym_db.RegisterMessage(RequestDeleteSpace)

RequestLoadSpaces = _reflection.GeneratedProtocolMessageType('RequestLoadSpaces', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADSPACES,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestLoadSpaces)
  })
_sym_db.RegisterMessage(RequestLoadSpaces)

ResponseLoadSpaces = _reflection.GeneratedProtocolMessageType('ResponseLoadSpaces', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADSPACES,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseLoadSpaces)
  })
_sym_db.RegisterMessage(ResponseLoadSpaces)

RequestStreamSpaceMembers = _reflection.GeneratedProtocolMessageType('RequestStreamSpaceMembers', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSTREAMSPACEMEMBERS,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestStreamSpaceMembers)
  })
_sym_db.RegisterMessage(RequestStreamSpaceMembers)

SpaceMemberWithPeer = _reflection.GeneratedProtocolMessageType('SpaceMemberWithPeer', (_message.Message,), {
  'DESCRIPTOR' : _SPACEMEMBERWITHPEER,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.SpaceMemberWithPeer)
  })
_sym_db.RegisterMessage(SpaceMemberWithPeer)

RequestSetTitle = _reflection.GeneratedProtocolMessageType('RequestSetTitle', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETTITLE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetTitle)
  })
_sym_db.RegisterMessage(RequestSetTitle)

RequestSetShortname = _reflection.GeneratedProtocolMessageType('RequestSetShortname', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETSHORTNAME,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetShortname)
  })
_sym_db.RegisterMessage(RequestSetShortname)

RequestSetAbout = _reflection.GeneratedProtocolMessageType('RequestSetAbout', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETABOUT,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetAbout)
  })
_sym_db.RegisterMessage(RequestSetAbout)

RequestSetAvatar = _reflection.GeneratedProtocolMessageType('RequestSetAvatar', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETAVATAR,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSetAvatar)
  })
_sym_db.RegisterMessage(RequestSetAvatar)

RequestSpaceInvite = _reflection.GeneratedProtocolMessageType('RequestSpaceInvite', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSPACEINVITE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSpaceInvite)
  })
_sym_db.RegisterMessage(RequestSpaceInvite)

RequestSpaceKick = _reflection.GeneratedProtocolMessageType('RequestSpaceKick', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSPACEKICK,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSpaceKick)
  })
_sym_db.RegisterMessage(RequestSpaceKick)

RequestSpaceLeave = _reflection.GeneratedProtocolMessageType('RequestSpaceLeave', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSPACELEAVE,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestSpaceLeave)
  })
_sym_db.RegisterMessage(RequestSpaceLeave)

RequestGetSpaceInviteUrl = _reflection.GeneratedProtocolMessageType('RequestGetSpaceInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETSPACEINVITEURL,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetSpaceInviteUrl)
  })
_sym_db.RegisterMessage(RequestGetSpaceInviteUrl)

ResponseSpaceInviteUrl = _reflection.GeneratedProtocolMessageType('ResponseSpaceInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESPACEINVITEURL,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseSpaceInviteUrl)
  })
_sym_db.RegisterMessage(ResponseSpaceInviteUrl)

RequestRevokeSpaceInviteUrl = _reflection.GeneratedProtocolMessageType('RequestRevokeSpaceInviteUrl', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREVOKESPACEINVITEURL,
  '__module__' : 'spaces_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRevokeSpaceInviteUrl)
  })
_sym_db.RegisterMessage(RequestRevokeSpaceInviteUrl)


DESCRIPTOR._options = None
_REQUESTCREATESPACE._options = None
_RESPONSESPACE._options = None
_RESPONSESPACEMEMBER._options = None
_REQUESTDELETESPACE._options = None
_REQUESTLOADSPACES._options = None
_RESPONSELOADSPACES._options = None
_REQUESTSTREAMSPACEMEMBERS._options = None
_REQUESTSETTITLE._options = None
_REQUESTSETSHORTNAME._options = None
_REQUESTSETABOUT._options = None
_REQUESTSETAVATAR._options = None
_REQUESTSPACEINVITE._options = None
_REQUESTSPACEKICK._options = None
_REQUESTSPACELEAVE._options = None
_REQUESTGETSPACEINVITEURL._options = None
_RESPONSESPACEINVITEURL._options = None
_REQUESTREVOKESPACEINVITEURL._options = None

_SPACES = _descriptor.ServiceDescriptor(
  name='Spaces',
  full_name='dialog.Spaces',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3249,
  serialized_end=4195,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSpace',
    full_name='dialog.Spaces.CreateSpace',
    index=0,
    containing_service=None,
    input_type=_REQUESTCREATESPACE,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSpace',
    full_name='dialog.Spaces.DeleteSpace',
    index=1,
    containing_service=None,
    input_type=_REQUESTDELETESPACE,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTitle',
    full_name='dialog.Spaces.SetTitle',
    index=2,
    containing_service=None,
    input_type=_REQUESTSETTITLE,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetShortname',
    full_name='dialog.Spaces.SetShortname',
    index=3,
    containing_service=None,
    input_type=_REQUESTSETSHORTNAME,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAbout',
    full_name='dialog.Spaces.SetAbout',
    index=4,
    containing_service=None,
    input_type=_REQUESTSETABOUT,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAvatar',
    full_name='dialog.Spaces.SetAvatar',
    index=5,
    containing_service=None,
    input_type=_REQUESTSETAVATAR,
    output_type=_RESPONSESPACE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadSpaces',
    full_name='dialog.Spaces.LoadSpaces',
    index=6,
    containing_service=None,
    input_type=_REQUESTLOADSPACES,
    output_type=_RESPONSELOADSPACES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadSpaceMembers',
    full_name='dialog.Spaces.LoadSpaceMembers',
    index=7,
    containing_service=None,
    input_type=_REQUESTSTREAMSPACEMEMBERS,
    output_type=_SPACEMEMBERWITHPEER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Invite',
    full_name='dialog.Spaces.Invite',
    index=8,
    containing_service=None,
    input_type=_REQUESTSPACEINVITE,
    output_type=_RESPONSESPACEMEMBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Kick',
    full_name='dialog.Spaces.Kick',
    index=9,
    containing_service=None,
    input_type=_REQUESTSPACEKICK,
    output_type=_RESPONSESPACEMEMBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Leave',
    full_name='dialog.Spaces.Leave',
    index=10,
    containing_service=None,
    input_type=_REQUESTSPACELEAVE,
    output_type=_RESPONSESPACEMEMBER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSpaceInviteUrl',
    full_name='dialog.Spaces.GetSpaceInviteUrl',
    index=11,
    containing_service=None,
    input_type=_REQUESTGETSPACEINVITEURL,
    output_type=_RESPONSESPACEINVITEURL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeSpaceInviteUrl',
    full_name='dialog.Spaces.RevokeSpaceInviteUrl',
    index=12,
    containing_service=None,
    input_type=_REQUESTREVOKESPACEINVITEURL,
    output_type=_RESPONSESPACEINVITEURL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SPACES)

DESCRIPTOR.services_by_name['Spaces'] = _SPACES

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import miscellaneous_pb2 as miscellaneous__pb2
from . import web_rtc_pb2 as web__rtc__pb2


class WebRTCStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCallInfo = channel.unary_unary(
                '/dialog.WebRTC/GetCallInfo',
                request_serializer=web__rtc__pb2.RequestGetCallInfo.SerializeToString,
                response_deserializer=web__rtc__pb2.ResponseGetCallInfo.FromString,
                )
        self.LoadCalls = channel.unary_unary(
                '/dialog.WebRTC/LoadCalls',
                request_serializer=web__rtc__pb2.RequestLoadCalls.SerializeToString,
                response_deserializer=web__rtc__pb2.ResponseLoadCalls.FromString,
                )
        self.DoCall = channel.unary_unary(
                '/dialog.WebRTC/DoCall',
                request_serializer=web__rtc__pb2.RequestDoCall.SerializeToString,
                response_deserializer=web__rtc__pb2.ResponseDoCall.FromString,
                )
        self.JoinCall = channel.unary_unary(
                '/dialog.WebRTC/JoinCall',
                request_serializer=web__rtc__pb2.RequestJoinCall.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.RejectCall = channel.unary_unary(
                '/dialog.WebRTC/RejectCall',
                request_serializer=web__rtc__pb2.RequestRejectCall.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.ChangeCallDisplayName = channel.unary_unary(
                '/dialog.WebRTC/ChangeCallDisplayName',
                request_serializer=web__rtc__pb2.RequestChangeCallDisplayName.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )
        self.DeleteCall = channel.unary_unary(
                '/dialog.WebRTC/DeleteCall',
                request_serializer=web__rtc__pb2.RequestDeleteCall.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseVoid.FromString,
                )


class WebRTCServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCallInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadCalls(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DoCall(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def JoinCall(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RejectCall(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeCallDisplayName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCall(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebRTCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCallInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCallInfo,
                    request_deserializer=web__rtc__pb2.RequestGetCallInfo.FromString,
                    response_serializer=web__rtc__pb2.ResponseGetCallInfo.SerializeToString,
            ),
            'LoadCalls': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadCalls,
                    request_deserializer=web__rtc__pb2.RequestLoadCalls.FromString,
                    response_serializer=web__rtc__pb2.ResponseLoadCalls.SerializeToString,
            ),
            'DoCall': grpc.unary_unary_rpc_method_handler(
                    servicer.DoCall,
                    request_deserializer=web__rtc__pb2.RequestDoCall.FromString,
                    response_serializer=web__rtc__pb2.ResponseDoCall.SerializeToString,
            ),
            'JoinCall': grpc.unary_unary_rpc_method_handler(
                    servicer.JoinCall,
                    request_deserializer=web__rtc__pb2.RequestJoinCall.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'RejectCall': grpc.unary_unary_rpc_method_handler(
                    servicer.RejectCall,
                    request_deserializer=web__rtc__pb2.RequestRejectCall.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'ChangeCallDisplayName': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeCallDisplayName,
                    request_deserializer=web__rtc__pb2.RequestChangeCallDisplayName.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
            'DeleteCall': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCall,
                    request_deserializer=web__rtc__pb2.RequestDeleteCall.FromString,
                    response_serializer=miscellaneous__pb2.ResponseVoid.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.WebRTC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WebRTC(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCallInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/GetCallInfo',
            web__rtc__pb2.RequestGetCallInfo.SerializeToString,
            web__rtc__pb2.ResponseGetCallInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadCalls(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/LoadCalls',
            web__rtc__pb2.RequestLoadCalls.SerializeToString,
            web__rtc__pb2.ResponseLoadCalls.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DoCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/DoCall',
            web__rtc__pb2.RequestDoCall.SerializeToString,
            web__rtc__pb2.ResponseDoCall.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def JoinCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/JoinCall',
            web__rtc__pb2.RequestJoinCall.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RejectCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/RejectCall',
            web__rtc__pb2.RequestRejectCall.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeCallDisplayName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/ChangeCallDisplayName',
            web__rtc__pb2.RequestChangeCallDisplayName.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.WebRTC/DeleteCall',
            web__rtc__pb2.RequestDeleteCall.SerializeToString,
            miscellaneous__pb2.ResponseVoid.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import contacts_pb2 as contacts__pb2
from . import miscellaneous_pb2 as miscellaneous__pb2


class ContactsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ImportContacts = channel.unary_unary(
                '/dialog.Contacts/ImportContacts',
                request_serializer=contacts__pb2.RequestImportContacts.SerializeToString,
                response_deserializer=contacts__pb2.ResponseImportContacts.FromString,
                )
        self.DeferredImportContacts = channel.unary_unary(
                '/dialog.Contacts/DeferredImportContacts',
                request_serializer=contacts__pb2.RequestDeferredImportContacts.SerializeToString,
                response_deserializer=contacts__pb2.ResponseDeferredImportContacts.FromString,
                )
        self.GetContacts = channel.unary_unary(
                '/dialog.Contacts/GetContacts',
                request_serializer=contacts__pb2.RequestGetContacts.SerializeToString,
                response_deserializer=contacts__pb2.ResponseGetContacts.FromString,
                )
        self.RemoveContact = channel.unary_unary(
                '/dialog.Contacts/RemoveContact',
                request_serializer=contacts__pb2.RequestRemoveContact.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.AddContact = channel.unary_unary(
                '/dialog.Contacts/AddContact',
                request_serializer=contacts__pb2.RequestAddContact.SerializeToString,
                response_deserializer=miscellaneous__pb2.ResponseSeq.FromString,
                )
        self.SearchContacts = channel.unary_unary(
                '/dialog.Contacts/SearchContacts',
                request_serializer=contacts__pb2.RequestSearchContacts.SerializeToString,
                response_deserializer=contacts__pb2.ResponseSearchContacts.FromString,
                )


class ContactsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ImportContacts(self, request, context):
        """/ Import contacts and wait while query is not finished
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeferredImportContacts(self, request, context):
        """/ Same as above, but without waiting response
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContacts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveContact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddContact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchContacts(self, request, context):
        """/ Search contacts by query string
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ContactsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ImportContacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportContacts,
                    request_deserializer=contacts__pb2.RequestImportContacts.FromString,
                    response_serializer=contacts__pb2.ResponseImportContacts.SerializeToString,
            ),
            'DeferredImportContacts': grpc.unary_unary_rpc_method_handler(
                    servicer.DeferredImportContacts,
                    request_deserializer=contacts__pb2.RequestDeferredImportContacts.FromString,
                    response_serializer=contacts__pb2.ResponseDeferredImportContacts.SerializeToString,
            ),
            'GetContacts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContacts,
                    request_deserializer=contacts__pb2.RequestGetContacts.FromString,
                    response_serializer=contacts__pb2.ResponseGetContacts.SerializeToString,
            ),
            'RemoveContact': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveContact,
                    request_deserializer=contacts__pb2.RequestRemoveContact.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'AddContact': grpc.unary_unary_rpc_method_handler(
                    servicer.AddContact,
                    request_deserializer=contacts__pb2.RequestAddContact.FromString,
                    response_serializer=miscellaneous__pb2.ResponseSeq.SerializeToString,
            ),
            'SearchContacts': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchContacts,
                    request_deserializer=contacts__pb2.RequestSearchContacts.FromString,
                    response_serializer=contacts__pb2.ResponseSearchContacts.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Contacts', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Contacts(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ImportContacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Contacts/ImportContacts',
            contacts__pb2.RequestImportContacts.SerializeToString,
            contacts__pb2.ResponseImportContacts.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeferredImportContacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Contacts/DeferredImportContacts',
            contacts__pb2.RequestDeferredImportContacts.SerializeToString,
            contacts__pb2.ResponseDeferredImportContacts.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Contacts/GetContacts',
            contacts__pb2.RequestGetContacts.SerializeToString,
            contacts__pb2.ResponseGetContacts.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveContact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Contacts/RemoveContact',
            contacts__pb2.RequestRemoveContact.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddContact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Contacts/AddContact',
            contacts__pb2.RequestAddContact.SerializeToString,
            miscellaneous__pb2.ResponseSeq.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchContacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Contacts/SearchContacts',
            contacts__pb2.RequestSearchContacts.SerializeToString,
            contacts__pb2.ResponseSearchContacts.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: registration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='registration.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12registration.proto\x12\x06\x64ialog\x1a\x15scalapb/scalapb.proto\x1a\x1cgoogle/api/annotations.proto\"\x81\x01\n\x15RequestRegisterDevice\x12\x11\n\tclient_pk\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\x05\x12\x11\n\tapp_title\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65vice_title\x18\x04 \x01(\t:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"\x9f\x01\n\x15ResponseDeviceRequest\x12\x11\n\tserver_pk\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61uth_id\x18\x02 \x01(\x03\x12\r\n\x05token\x18\x03 \x01(\t\x12\x34\n\x0f\x61uth_method_seq\x18\x04 \x03(\x0e\x32\x1b.dialog.AuthorizationMethod:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"!\n\x1fRegisterDeprecatedDeviceRequest\"C\n\x1dRequestExchangeAuthIdForToken\x12\x0f\n\x07\x61uth_id\x18\x01 \x01(\x03\x12\x11\n\tsignature\x18\x02 \x01(\x0c*\xe0\x01\n\x13\x41uthorizationMethod\x12 \n\x1c\x41UTHORIZATION_METHOD_NOTHING\x10\x00\x12!\n\x1d\x41UTHORIZATION_METHOD_USERNAME\x10\x01\x12\x1e\n\x1a\x41UTHORIZATION_METHOD_PHONE\x10\x02\x12\x1e\n\x1a\x41UTHORIZATION_METHOD_EMAIL\x10\x03\x12$\n AUTHORIZATION_METHOD_CERTIFICATE\x10\x04\x12\x1e\n\x1a\x41UTHORIZATION_METHOD_OAUTH\x10\x05\x32\xc9\x03\n\x0cRegistration\x12\x97\x01\n\x16\x45xchangeAuthIdForToken\x12%.dialog.RequestExchangeAuthIdForToken\x1a\x1d.dialog.ResponseDeviceRequest\"7\x82\xd3\xe4\x93\x02\x31\",/v1/grpc/Registration/ExchangeAuthIdForToken:\x01*\x12\x7f\n\x0eRegisterDevice\x12\x1d.dialog.RequestRegisterDevice\x1a\x1d.dialog.ResponseDeviceRequest\"/\x82\xd3\xe4\x93\x02)\"$/v1/grpc/Registration/RegisterDevice:\x01*\x12\x9d\x01\n\x18RegisterDeprecatedDevice\x12\'.dialog.RegisterDeprecatedDeviceRequest\x1a\x1d.dialog.ResponseDeviceRequest\"9\x82\xd3\xe4\x93\x02\x33\"./v1/grpc/Registration/RegisterDeprecatedDevice:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_AUTHORIZATIONMETHOD = _descriptor.EnumDescriptor(
  name='AuthorizationMethod',
  full_name='dialog.AuthorizationMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_METHOD_NOTHING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_METHOD_USERNAME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_METHOD_PHONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_METHOD_EMAIL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_METHOD_CERTIFICATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_METHOD_OAUTH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=706,
)
_sym_db.RegisterEnumDescriptor(_AUTHORIZATIONMETHOD)

AuthorizationMethod = enum_type_wrapper.EnumTypeWrapper(_AUTHORIZATIONMETHOD)
AUTHORIZATION_METHOD_NOTHING = 0
AUTHORIZATION_METHOD_USERNAME = 1
AUTHORIZATION_METHOD_PHONE = 2
AUTHORIZATION_METHOD_EMAIL = 3
AUTHORIZATION_METHOD_CERTIFICATE = 4
AUTHORIZATION_METHOD_OAUTH = 5



_REQUESTREGISTERDEVICE = _descriptor.Descriptor(
  name='RequestRegisterDevice',
  full_name='dialog.RequestRegisterDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_pk', full_name='dialog.RequestRegisterDevice.client_pk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='dialog.RequestRegisterDevice.app_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_title', full_name='dialog.RequestRegisterDevice.app_title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_title', full_name='dialog.RequestRegisterDevice.device_title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=213,
)


_RESPONSEDEVICEREQUEST = _descriptor.Descriptor(
  name='ResponseDeviceRequest',
  full_name='dialog.ResponseDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_pk', full_name='dialog.ResponseDeviceRequest.server_pk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_id', full_name='dialog.ResponseDeviceRequest.auth_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.ResponseDeviceRequest.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_method_seq', full_name='dialog.ResponseDeviceRequest.auth_method_seq', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=375,
)


_REGISTERDEPRECATEDDEVICEREQUEST = _descriptor.Descriptor(
  name='RegisterDeprecatedDeviceRequest',
  full_name='dialog.RegisterDeprecatedDeviceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=410,
)


_REQUESTEXCHANGEAUTHIDFORTOKEN = _descriptor.Descriptor(
  name='RequestExchangeAuthIdForToken',
  full_name='dialog.RequestExchangeAuthIdForToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_id', full_name='dialog.RequestExchangeAuthIdForToken.auth_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='dialog.RequestExchangeAuthIdForToken.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=479,
)

_RESPONSEDEVICEREQUEST.fields_by_name['auth_method_seq'].enum_type = _AUTHORIZATIONMETHOD
DESCRIPTOR.message_types_by_name['RequestRegisterDevice'] = _REQUESTREGISTERDEVICE
DESCRIPTOR.message_types_by_name['ResponseDeviceRequest'] = _RESPONSEDEVICEREQUEST
DESCRIPTOR.message_types_by_name['RegisterDeprecatedDeviceRequest'] = _REGISTERDEPRECATEDDEVICEREQUEST
DESCRIPTOR.message_types_by_name['RequestExchangeAuthIdForToken'] = _REQUESTEXCHANGEAUTHIDFORTOKEN
DESCRIPTOR.enum_types_by_name['AuthorizationMethod'] = _AUTHORIZATIONMETHOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestRegisterDevice = _reflection.GeneratedProtocolMessageType('RequestRegisterDevice', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREGISTERDEVICE,
  '__module__' : 'registration_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRegisterDevice)
  })
_sym_db.RegisterMessage(RequestRegisterDevice)

ResponseDeviceRequest = _reflection.GeneratedProtocolMessageType('ResponseDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDEVICEREQUEST,
  '__module__' : 'registration_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseDeviceRequest)
  })
_sym_db.RegisterMessage(ResponseDeviceRequest)

RegisterDeprecatedDeviceRequest = _reflection.GeneratedProtocolMessageType('RegisterDeprecatedDeviceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDEPRECATEDDEVICEREQUEST,
  '__module__' : 'registration_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RegisterDeprecatedDeviceRequest)
  })
_sym_db.RegisterMessage(RegisterDeprecatedDeviceRequest)

RequestExchangeAuthIdForToken = _reflection.GeneratedProtocolMessageType('RequestExchangeAuthIdForToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTEXCHANGEAUTHIDFORTOKEN,
  '__module__' : 'registration_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestExchangeAuthIdForToken)
  })
_sym_db.RegisterMessage(RequestExchangeAuthIdForToken)


DESCRIPTOR._options = None
_REQUESTREGISTERDEVICE._options = None
_RESPONSEDEVICEREQUEST._options = None

_REGISTRATION = _descriptor.ServiceDescriptor(
  name='Registration',
  full_name='dialog.Registration',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=709,
  serialized_end=1166,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExchangeAuthIdForToken',
    full_name='dialog.Registration.ExchangeAuthIdForToken',
    index=0,
    containing_service=None,
    input_type=_REQUESTEXCHANGEAUTHIDFORTOKEN,
    output_type=_RESPONSEDEVICEREQUEST,
    serialized_options=b'\202\323\344\223\0021\",/v1/grpc/Registration/ExchangeAuthIdForToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterDevice',
    full_name='dialog.Registration.RegisterDevice',
    index=1,
    containing_service=None,
    input_type=_REQUESTREGISTERDEVICE,
    output_type=_RESPONSEDEVICEREQUEST,
    serialized_options=b'\202\323\344\223\002)\"$/v1/grpc/Registration/RegisterDevice:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterDeprecatedDevice',
    full_name='dialog.Registration.RegisterDeprecatedDevice',
    index=2,
    containing_service=None,
    input_type=_REGISTERDEPRECATEDDEVICEREQUEST,
    output_type=_RESPONSEDEVICEREQUEST,
    serialized_options=b'\202\323\344\223\0023\"./v1/grpc/Registration/RegisterDeprecatedDevice:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REGISTRATION)

DESCRIPTOR.services_by_name['Registration'] = _REGISTRATION

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway_service.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'Z\006dialog\242\002\003API\272\002\003API',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15gateway_service.proto\x12\x06\x64ialog\x1a\x1egoogle/protobuf/wrappers.proto\"c\n\x14GetDifferenceCommand\x12(\n\x03seq\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05state\x18\x02 \x01(\x0c\x12\x12\n\nconfigHash\x18\x03 \x01(\x03\"P\n\rServiceUpdate\x12\x35\n\x0eobsoleteUpdate\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValueH\x00\x42\x08\n\x06updateB\x14Z\x06\x64ialog\xa2\x02\x03\x41PI\xba\x02\x03\x41PIb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_GETDIFFERENCECOMMAND = _descriptor.Descriptor(
  name='GetDifferenceCommand',
  full_name='dialog.GetDifferenceCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.GetDifferenceCommand.seq', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.GetDifferenceCommand.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configHash', full_name='dialog.GetDifferenceCommand.configHash', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=164,
)


_SERVICEUPDATE = _descriptor.Descriptor(
  name='ServiceUpdate',
  full_name='dialog.ServiceUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obsoleteUpdate', full_name='dialog.ServiceUpdate.obsoleteUpdate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='update', full_name='dialog.ServiceUpdate.update',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=166,
  serialized_end=246,
)

_GETDIFFERENCECOMMAND.fields_by_name['seq'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_SERVICEUPDATE.fields_by_name['obsoleteUpdate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_SERVICEUPDATE.oneofs_by_name['update'].fields.append(
  _SERVICEUPDATE.fields_by_name['obsoleteUpdate'])
_SERVICEUPDATE.fields_by_name['obsoleteUpdate'].containing_oneof = _SERVICEUPDATE.oneofs_by_name['update']
DESCRIPTOR.message_types_by_name['GetDifferenceCommand'] = _GETDIFFERENCECOMMAND
DESCRIPTOR.message_types_by_name['ServiceUpdate'] = _SERVICEUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDifferenceCommand = _reflection.GeneratedProtocolMessageType('GetDifferenceCommand', (_message.Message,), {
  'DESCRIPTOR' : _GETDIFFERENCECOMMAND,
  '__module__' : 'gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:dialog.GetDifferenceCommand)
  })
_sym_db.RegisterMessage(GetDifferenceCommand)

ServiceUpdate = _reflection.GeneratedProtocolMessageType('ServiceUpdate', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEUPDATE,
  '__module__' : 'gateway_service_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ServiceUpdate)
  })
_sym_db.RegisterMessage(ServiceUpdate)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reactions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import peers_pb2 as peers__pb2
from . import definitions_pb2 as definitions__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='reactions.proto',
  package='dialog.reactions',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0freactions.proto\x12\x10\x64ialog.reactions\x1a\x1cgoogle/api/annotations.proto\x1a\x0bpeers.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x15scalapb/scalapb.proto\x1a\x1bgoogle/protobuf/empty.proto\"=\n\x08Reaction\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05users\x18\x02 \x03(\x05\x12\x14\n\x0cusers_amount\x18\x03 \x01(\x05\"a\n\x10MessageReactions\x12\x1e\n\x03mid\x18\x01 \x01(\x0b\x32\x11.dialog.UUIDValue\x12-\n\treactions\x18\x02 \x03(\x0b\x32\x1a.dialog.reactions.Reaction\"\x9e\x01\n\x16MessageReactionsUpdate\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12;\n\x0fmessageReaction\x18\x02 \x01(\x0b\x32\".dialog.reactions.MessageReactions\x12\x12\n\npeer_clock\x18\x03 \x01(\x03\x12\x17\n\x0fprev_peer_clock\x18\x04 \x01(\x03\"E\n\x13GetReactionsRequest\x12\x12\n\nfrom_clock\x18\x01 \x01(\x03\x12\x1a\n\x04peer\x18\x02 \x01(\x0b\x32\x0c.dialog.Peer\"\x80\x01\n\x14GetReactionsResponse\x12<\n\x10messageReactions\x18\x01 \x03(\x0b\x32\".dialog.reactions.MessageReactions\x12\x12\n\npeer_clock\x18\x02 \x01(\x03\x12\x16\n\x0enext_available\x18\x03 \x01(\x08\"e\n\x19RequestSetMessageReaction\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12\x1e\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\"h\n\x1cRequestRemoveMessageReaction\x12\x1a\n\x04peer\x18\x01 \x01(\x0b\x32\x0c.dialog.Peer\x12\x1e\n\x03mid\x18\x02 \x01(\x0b\x32\x11.dialog.UUIDValue\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t2\xbc\x03\n\tReactions\x12\x89\x01\n\x0cGetReactions\x12%.dialog.reactions.GetReactionsRequest\x1a&.dialog.reactions.GetReactionsResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/grpc/Reactions/GetReactions:\x01*\x12\x8b\x01\n\x12MessageSetReaction\x12+.dialog.reactions.RequestSetMessageReaction\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/v1/grpc/Reactions/MessageSetReaction:\x01*\x12\x94\x01\n\x15MessageRemoveReaction\x12..dialog.reactions.RequestRemoveMessageReaction\x1a\x16.google.protobuf.Empty\"3\x82\xd3\xe4\x93\x02-\"(/v1/grpc/Reactions/MessageRemoveReaction:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_REACTION = _descriptor.Descriptor(
  name='Reaction',
  full_name='dialog.reactions.Reaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.reactions.Reaction.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users', full_name='dialog.reactions.Reaction.users', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='users_amount', full_name='dialog.reactions.Reaction.users_amount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=212,
)


_MESSAGEREACTIONS = _descriptor.Descriptor(
  name='MessageReactions',
  full_name='dialog.reactions.MessageReactions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.reactions.MessageReactions.mid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='dialog.reactions.MessageReactions.reactions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=311,
)


_MESSAGEREACTIONSUPDATE = _descriptor.Descriptor(
  name='MessageReactionsUpdate',
  full_name='dialog.reactions.MessageReactionsUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.MessageReactionsUpdate.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageReaction', full_name='dialog.reactions.MessageReactionsUpdate.messageReaction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_clock', full_name='dialog.reactions.MessageReactionsUpdate.peer_clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_peer_clock', full_name='dialog.reactions.MessageReactionsUpdate.prev_peer_clock', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=472,
)


_GETREACTIONSREQUEST = _descriptor.Descriptor(
  name='GetReactionsRequest',
  full_name='dialog.reactions.GetReactionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_clock', full_name='dialog.reactions.GetReactionsRequest.from_clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.GetReactionsRequest.peer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=543,
)


_GETREACTIONSRESPONSE = _descriptor.Descriptor(
  name='GetReactionsResponse',
  full_name='dialog.reactions.GetReactionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageReactions', full_name='dialog.reactions.GetReactionsResponse.messageReactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_clock', full_name='dialog.reactions.GetReactionsResponse.peer_clock', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_available', full_name='dialog.reactions.GetReactionsResponse.next_available', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=674,
)


_REQUESTSETMESSAGEREACTION = _descriptor.Descriptor(
  name='RequestSetMessageReaction',
  full_name='dialog.reactions.RequestSetMessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.RequestSetMessageReaction.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.reactions.RequestSetMessageReaction.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.reactions.RequestSetMessageReaction.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=777,
)


_REQUESTREMOVEMESSAGEREACTION = _descriptor.Descriptor(
  name='RequestRemoveMessageReaction',
  full_name='dialog.reactions.RequestRemoveMessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.reactions.RequestRemoveMessageReaction.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mid', full_name='dialog.reactions.RequestRemoveMessageReaction.mid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='dialog.reactions.RequestRemoveMessageReaction.code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=883,
)

_MESSAGEREACTIONS.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_MESSAGEREACTIONS.fields_by_name['reactions'].message_type = _REACTION
_MESSAGEREACTIONSUPDATE.fields_by_name['peer'].message_type = peers__pb2._PEER
_MESSAGEREACTIONSUPDATE.fields_by_name['messageReaction'].message_type = _MESSAGEREACTIONS
_GETREACTIONSREQUEST.fields_by_name['peer'].message_type = peers__pb2._PEER
_GETREACTIONSRESPONSE.fields_by_name['messageReactions'].message_type = _MESSAGEREACTIONS
_REQUESTSETMESSAGEREACTION.fields_by_name['peer'].message_type = peers__pb2._PEER
_REQUESTSETMESSAGEREACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
_REQUESTREMOVEMESSAGEREACTION.fields_by_name['peer'].message_type = peers__pb2._PEER
_REQUESTREMOVEMESSAGEREACTION.fields_by_name['mid'].message_type = definitions__pb2._UUIDVALUE
DESCRIPTOR.message_types_by_name['Reaction'] = _REACTION
DESCRIPTOR.message_types_by_name['MessageReactions'] = _MESSAGEREACTIONS
DESCRIPTOR.message_types_by_name['MessageReactionsUpdate'] = _MESSAGEREACTIONSUPDATE
DESCRIPTOR.message_types_by_name['GetReactionsRequest'] = _GETREACTIONSREQUEST
DESCRIPTOR.message_types_by_name['GetReactionsResponse'] = _GETREACTIONSRESPONSE
DESCRIPTOR.message_types_by_name['RequestSetMessageReaction'] = _REQUESTSETMESSAGEREACTION
DESCRIPTOR.message_types_by_name['RequestRemoveMessageReaction'] = _REQUESTREMOVEMESSAGEREACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reaction = _reflection.GeneratedProtocolMessageType('Reaction', (_message.Message,), {
  'DESCRIPTOR' : _REACTION,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.Reaction)
  })
_sym_db.RegisterMessage(Reaction)

MessageReactions = _reflection.GeneratedProtocolMessageType('MessageReactions', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREACTIONS,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.MessageReactions)
  })
_sym_db.RegisterMessage(MessageReactions)

MessageReactionsUpdate = _reflection.GeneratedProtocolMessageType('MessageReactionsUpdate', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEREACTIONSUPDATE,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.MessageReactionsUpdate)
  })
_sym_db.RegisterMessage(MessageReactionsUpdate)

GetReactionsRequest = _reflection.GeneratedProtocolMessageType('GetReactionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREACTIONSREQUEST,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.GetReactionsRequest)
  })
_sym_db.RegisterMessage(GetReactionsRequest)

GetReactionsResponse = _reflection.GeneratedProtocolMessageType('GetReactionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREACTIONSRESPONSE,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.GetReactionsResponse)
  })
_sym_db.RegisterMessage(GetReactionsResponse)

RequestSetMessageReaction = _reflection.GeneratedProtocolMessageType('RequestSetMessageReaction', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETMESSAGEREACTION,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.RequestSetMessageReaction)
  })
_sym_db.RegisterMessage(RequestSetMessageReaction)

RequestRemoveMessageReaction = _reflection.GeneratedProtocolMessageType('RequestRemoveMessageReaction', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREMOVEMESSAGEREACTION,
  '__module__' : 'reactions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.reactions.RequestRemoveMessageReaction)
  })
_sym_db.RegisterMessage(RequestRemoveMessageReaction)


DESCRIPTOR._options = None

_REACTIONS = _descriptor.ServiceDescriptor(
  name='Reactions',
  full_name='dialog.reactions.Reactions',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=886,
  serialized_end=1330,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetReactions',
    full_name='dialog.reactions.Reactions.GetReactions',
    index=0,
    containing_service=None,
    input_type=_GETREACTIONSREQUEST,
    output_type=_GETREACTIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\037/v1/grpc/Reactions/GetReactions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MessageSetReaction',
    full_name='dialog.reactions.Reactions.MessageSetReaction',
    index=1,
    containing_service=None,
    input_type=_REQUESTSETMESSAGEREACTION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002*\"%/v1/grpc/Reactions/MessageSetReaction:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MessageRemoveReaction',
    full_name='dialog.reactions.Reactions.MessageRemoveReaction',
    index=2,
    containing_service=None,
    input_type=_REQUESTREMOVEMESSAGEREACTION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002-\"(/v1/grpc/Reactions/MessageRemoveReaction:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REACTIONS)

DESCRIPTOR.services_by_name['Reactions'] = _REACTIONS

# @@protoc_insertion_point(module_scope)
